/* Emacs: this is -*- C -*- code, */
/* generated 2014-05-17T03:05:15-07 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_4 3
#define LABEL_17 5
#define LABEL_22 7
#define LABEL_18 9
#define TAG_19 3
#define LABEL_15 11
#define TAG_16 4
#define LABEL_27 13
#define LABEL_31 15
#define LABEL_13 17
#define TAG_14 7
#define LABEL_34 19
#define LABEL_11 21
#define TAG_12 9
#define LABEL_36 23
#define LABEL_37 25
#define LABEL_38 27
#define LABEL_39 29
#define LABEL_40 31
#define LABEL_9 33
#define TAG_10 15
#define LABEL_41 35
#define LABEL_42 37
#define LABEL_44 39
#define LABEL_45 41
#define LABEL_46 43
#define LABEL_47 45
#define LABEL_48 47
#define LABEL_49 49
#define LABEL_50 51
#define LABEL_51 53
#define LABEL_55 55
#define LABEL_56 57
#define LABEL_7 59
#define TAG_8 28
#define LABEL_57 61
#define LABEL_58 63
#define LABEL_59 65
#define LABEL_61 67
#define LABEL_5 69
#define TAG_6 33
#define LABEL_62 71
#define LABEL_63 73
#define LABEL_65 75
#define LABEL_20 77
#define LABEL_71 79
#define LABEL_21 81
#define LABEL_72 83
#define LABEL_24 85
#define TAG_25 41
#define LABEL_74 87
#define LABEL_28 89
#define LABEL_75 91
#define LABEL_76 93
#define LABEL_29 95
#define LABEL_77 97
#define LABEL_78 99
#define LABEL_30 101
#define LABEL_33 103
#define LABEL_80 105
#define LABEL_81 107
#define LABEL_82 109
#define LABEL_43 111
#define LABEL_83 113
#define LABEL_84 115
#define LABEL_52 117
#define TAG_53 57
#define LABEL_85 119
#define LABEL_86 121
#define LABEL_88 123
#define LABEL_64 125
#define LABEL_91 127
#define LABEL_66 129
#define LABEL_92 131
#define LABEL_67 133
#define LABEL_68 135
#define TAG_69 66
#define LABEL_95 137
#define LABEL_73 139
#define LABEL_97 141
#define LABEL_87 143
#define LABEL_99 145
#define LABEL_100 147
#define LABEL_101 149
#define LABEL_102 151
#define LABEL_89 153
#define LABEL_93 155
#define LABEL_105 157
#define LABEL_94 159
#define LABEL_106 161
#define LABEL_107 163
#define LABEL_109 165
#define LABEL_96 167
#define LABEL_98 169
#define LABEL_112 171
#define LABEL_103 173
#define LABEL_113 175
#define LABEL_104 177
#define LABEL_108 179
#define LABEL_115 181
#define LABEL_110 183
#define LABEL_111 185
#define LABEL_116 187
#define LABEL_117 189
#define LABEL_118 191
#define LABEL_119 193
#define ENVIRONMENT_LABEL_3 248
#define DEBUGGING_LABEL_2 247
#define OBJECT_26 246
#define OBJECT_25 245
#define OBJECT_24 244
#define OBJECT_23 243
#define OBJECT_22 242
#define OBJECT_21 241
#define OBJECT_20 240
#define OBJECT_19 239
#define OBJECT_18 238
#define OBJECT_17 237
#define OBJECT_16 236
#define OBJECT_15 235
#define OBJECT_14 234
#define OBJECT_13 233
#define OBJECT_12 232
#define OBJECT_11 231
#define OBJECT_10 230
#define OBJECT_9 229
#define OBJECT_8 228
#define OBJECT_7 227
#define OBJECT_6 226
#define OBJECT_5 225
#define OBJECT_4 224
#define OBJECT_3 223
#define OBJECT_2 222
#define OBJECT_1 221
#define OBJECT_0 220
#define EXECUTE_CACHE_114 195
#define EXECUTE_CACHE_90 197
#define EXECUTE_CACHE_79 199
#define EXECUTE_CACHE_70 201
#define EXECUTE_CACHE_60 203
#define EXECUTE_CACHE_54 205
#define EXECUTE_CACHE_35 207
#define EXECUTE_CACHE_32 209
#define EXECUTE_CACHE_26 211
#define EXECUTE_CACHE_23 213
#define FREE_REFERENCE_3 216
#define FREE_REFERENCE_2 217
#define FREE_REFERENCE_1 218
#define FREE_REFERENCE_0 219
#define FREE_REFERENCES_LABEL_0 194
#define NUMBER_OF_LINKER_SECTIONS_1 2

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
outer_so_2998375ed3a84b78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
  machine_word Wrd92;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd150;
  machine_word Wrd149;
  machine_word Wrd148;
  machine_word Wrd147;
  machine_word Wrd143;
  machine_word Wrd144;
  machine_word Wrd140;
  machine_word Wrd134;
  machine_word Wrd135;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd130;
  machine_word Wrd129;
  machine_word Wrd118;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd101;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd111;
  machine_word Wrd110;
  machine_word Wrd95;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd96;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd82;
  machine_word Wrd80;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd69;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd166;
  machine_word Wrd162;
  machine_word Wrd161;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd156;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd32;
  machine_word Wrd81;
  machine_word Wrd67;
  machine_word Wrd70;
  machine_word Wrd68;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd76;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd57;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd34;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd16;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_17);
      goto continuation_11;

    case 2:
      current_block = (Rpc - LABEL_22);
      goto label_112;

    case 3:
      current_block = (Rpc - LABEL_18);
      goto outer_analysis_170;

    case 4:
      current_block = (Rpc - LABEL_15);
      goto prepare_application_169;

    case 5:
      current_block = (Rpc - LABEL_27);
      goto label_114;

    case 6:
      current_block = (Rpc - LABEL_31);
      goto label_113;

    case 7:
      current_block = (Rpc - LABEL_13);
      goto check_application_168;

    case 8:
      current_block = (Rpc - LABEL_34);
      goto label_115;

    case 9:
      current_block = (Rpc - LABEL_11);
      goto rvalue_passed_outB_167;

    case 10:
      current_block = (Rpc - LABEL_36);
      goto label_116;

    case 11:
      current_block = (Rpc - LABEL_37);
      goto label_117;

    case 12:
      current_block = (Rpc - LABEL_38);
      goto label_118;

    case 13:
      current_block = (Rpc - LABEL_39);
      goto label_119;

    case 14:
      current_block = (Rpc - LABEL_40);
      goto continuation_55;

    case 15:
      current_block = (Rpc - LABEL_9);
      goto block_passed_outB_166;

    case 16:
      current_block = (Rpc - LABEL_41);
      goto label_120;

    case 17:
      current_block = (Rpc - LABEL_42);
      goto label_129;

    case 18:
      current_block = (Rpc - LABEL_44);
      goto label_121;

    case 19:
      current_block = (Rpc - LABEL_45);
      goto label_122;

    case 20:
      current_block = (Rpc - LABEL_46);
      goto label_123;

    case 21:
      current_block = (Rpc - LABEL_47);
      goto label_124;

    case 22:
      current_block = (Rpc - LABEL_48);
      goto label_125;

    case 23:
      current_block = (Rpc - LABEL_49);
      goto label_126;

    case 24:
      current_block = (Rpc - LABEL_50);
      goto label_127;

    case 25:
      current_block = (Rpc - LABEL_51);
      goto label_128;

    case 26:
      current_block = (Rpc - LABEL_55);
      goto continuation_79;

    case 27:
      current_block = (Rpc - LABEL_56);
      goto continuation_80;

    case 28:
      current_block = (Rpc - LABEL_7);
      goto lvalue_externally_visibleB_165;

    case 29:
      current_block = (Rpc - LABEL_57);
      goto label_130;

    case 30:
      current_block = (Rpc - LABEL_58);
      goto label_131;

    case 31:
      current_block = (Rpc - LABEL_59);
      goto label_132;

    case 32:
      current_block = (Rpc - LABEL_61);
      goto continuation_97;

    case 33:
      current_block = (Rpc - LABEL_5);
      goto lvalue_passed_outB_103;

    case 34:
      current_block = (Rpc - LABEL_62);
      goto label_133;

    case 35:
      current_block = (Rpc - LABEL_63);
      goto label_135;

    case 36:
      current_block = (Rpc - LABEL_65);
      goto label_134;

    case 37:
      current_block = (Rpc - LABEL_20);
      goto continuation_12;

    case 38:
      current_block = (Rpc - LABEL_71);
      goto continuation_51;

    case 39:
      current_block = (Rpc - LABEL_21);
      goto Z__rvalue_passed_outB_53;

    case 40:
      current_block = (Rpc - LABEL_72);
      goto label_136;

    case 41:
      current_block = (Rpc - LABEL_24);
      goto lambda_171;

    case 42:
      current_block = (Rpc - LABEL_74);
      goto label_137;

    case 43:
      current_block = (Rpc - LABEL_28);
      goto continuation_32;

    case 44:
      current_block = (Rpc - LABEL_75);
      goto label_139;

    case 45:
      current_block = (Rpc - LABEL_76);
      goto label_138;

    case 46:
      current_block = (Rpc - LABEL_29);
      goto lambda_31;

    case 47:
      current_block = (Rpc - LABEL_77);
      goto label_140;

    case 48:
      current_block = (Rpc - LABEL_78);
      goto label_141;

    case 49:
      current_block = (Rpc - LABEL_30);
      goto continuation_28;

    case 50:
      current_block = (Rpc - LABEL_33);
      goto continuation_37;

    case 51:
      current_block = (Rpc - LABEL_80);
      goto label_144;

    case 52:
      current_block = (Rpc - LABEL_81);
      goto label_143;

    case 53:
      current_block = (Rpc - LABEL_82);
      goto label_142;

    case 54:
      current_block = (Rpc - LABEL_43);
      goto continuation_71;

    case 55:
      current_block = (Rpc - LABEL_83);
      goto label_145;

    case 56:
      current_block = (Rpc - LABEL_84);
      goto label_146;

    case 57:
      current_block = (Rpc - LABEL_52);
      goto lambda_172;

    case 58:
      current_block = (Rpc - LABEL_85);
      goto lvalue_passed_inB_90;

    case 59:
      current_block = (Rpc - LABEL_86);
      goto label_147;

    case 60:
      current_block = (Rpc - LABEL_88);
      goto label_148;

    case 61:
      current_block = (Rpc - LABEL_64);
      goto continuation_101;

    case 62:
      current_block = (Rpc - LABEL_91);
      goto continuation_105;

    case 63:
      current_block = (Rpc - LABEL_66);
      goto Z__lvalue_passed_outB_107;

    case 64:
      current_block = (Rpc - LABEL_92);
      goto label_149;

    case 65:
      current_block = (Rpc - LABEL_67);
      goto continuation_15;

    case 66:
      current_block = (Rpc - LABEL_68);
      goto lambda_173;

    case 67:
      current_block = (Rpc - LABEL_95);
      goto label_150;

    case 68:
      current_block = (Rpc - LABEL_73);
      goto continuation_2;

    case 69:
      current_block = (Rpc - LABEL_97);
      goto label_151;

    case 70:
      current_block = (Rpc - LABEL_87);
      goto continuation_85;

    case 71:
      current_block = (Rpc - LABEL_99);
      goto label_152;

    case 72:
      current_block = (Rpc - LABEL_100);
      goto Z__lvalue_passed_inB_95;

    case 73:
      current_block = (Rpc - LABEL_101);
      goto label_154;

    case 74:
      current_block = (Rpc - LABEL_102);
      goto label_153;

    case 75:
      current_block = (Rpc - LABEL_89);
      goto continuation_102;

    case 76:
      current_block = (Rpc - LABEL_93);
      goto continuation_24;

    case 77:
      current_block = (Rpc - LABEL_105);
      goto continuation_17;

    case 78:
      current_block = (Rpc - LABEL_94);
      goto lambda_23;

    case 79:
      current_block = (Rpc - LABEL_106);
      goto label_155;

    case 80:
      current_block = (Rpc - LABEL_107);
      goto label_157;

    case 81:
      current_block = (Rpc - LABEL_109);
      goto label_156;

    case 82:
      current_block = (Rpc - LABEL_96);
      goto continuation_4;

    case 83:
      current_block = (Rpc - LABEL_98);
      goto lambda_87;

    case 84:
      current_block = (Rpc - LABEL_112);
      goto label_158;

    case 85:
      current_block = (Rpc - LABEL_103);
      goto lambda_93;

    case 86:
      current_block = (Rpc - LABEL_113);
      goto label_159;

    case 87:
      current_block = (Rpc - LABEL_104);
      goto continuation_25;

    case 88:
      current_block = (Rpc - LABEL_108);
      goto continuation_21;

    case 89:
      current_block = (Rpc - LABEL_115);
      goto label_160;

    case 90:
      current_block = (Rpc - LABEL_110);
      goto continuation_8;

    case 91:
      current_block = (Rpc - LABEL_111);
      goto lambda_7;

    case 92:
      current_block = (Rpc - LABEL_116);
      goto label_162;

    case 93:
      current_block = (Rpc - LABEL_117);
      goto label_161;

    case 94:
      current_block = (Rpc - LABEL_118);
      goto label_183;

    case 95:
      current_block = (Rpc - LABEL_119);
      goto expression_111;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_111)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_118])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_183)
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1]), 3);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd52.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_5])));
  Rhp += 1;
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd52.pObj)));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd50.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7])));
  Rhp += 1;
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd50.pObj)));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd48.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9])));
  Rhp += 1;
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd46.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11])));
  Rhp += 1;
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd46.pObj)));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd44.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13])));
  Rhp += 1;
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd44.pObj)));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd42.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_15])));
  Rhp += 1;
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd42.pObj)));
  (* (--Rsp)) = (Wrd43.Obj);
  ((Wrd42.pObj) [2]) = (Wrd47.Obj);
  ((Wrd44.pObj) [2]) = (Wrd47.Obj);
  ((Wrd46.pObj) [2]) = (Wrd7.Obj);
  ((Wrd48.pObj) [2]) = (Wrd51.Obj);
  ((Wrd50.pObj) [2]) = (Wrd53.Obj);
  ((Wrd52.pObj) [2]) = (Wrd47.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_18])));
  Rhp += 3;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  Wrd20 = Wrd15;
  ((Wrd20.pObj) [2]) = (Wrd49.Obj);
  ((Wrd20.pObj) [3]) = (Wrd45.Obj);
  ((Wrd20.pObj) [4]) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_185;
  Wrd10 = Wrd14;

DEFLABEL (label_184)
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_20);
  (Wrd6.Obj) = (Rsp [6]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  ((Wrd7.pObj) [0]) = Rvl;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_69);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_68])));
  Rhp += 1;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd13 = Wrd12;
  (Wrd14.Obj) = (Rsp [6]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = ((Wrd7.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_67);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [8]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_93);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [8]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70]));

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_104);
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [8]));
  goto pop_return;

DEFLABEL (label_185)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_22])), (Wrd11.pObj));

DEFLABEL (label_112)
  (Wrd10.Obj) = Rvl;
  goto label_184;

DEFLABEL (outer_analysis_170)
  CLOSURE_HEADER (LABEL_18);

DEFLABEL (outer_analysis_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_24])));
  Rhp += 5;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd18 = Wrd7;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  ((Wrd18.pObj) [2]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd20.pObj) [4]);
  ((Wrd18.pObj) [3]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd18.pObj) [4]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [5]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd18.pObj) [6]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd22.Obj) = ((Wrd20.pObj) [3]);
  (Rsp [2]) = (Wrd22.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26]));

DEFLABEL (prepare_application_169)
  CLOSURE_HEADER (LABEL_15);

DEFLABEL (prepare_application_35)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 10))
    goto label_194;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd37.Lng))))
    goto label_194;
  ((Wrd35.pObj) [13]) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_193)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd22.Obj) = (Rsp [4]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_192;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd21.Lng))))
    goto label_192;
  (Wrd15.Obj) = ((Wrd19.pObj) [10]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_191)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_30);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_28);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_186;
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_186)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_190;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd34.Lng))))
    goto label_190;
  (Wrd28.Obj) = (current_block [OBJECT_21]);
  ((Wrd32.pObj) [13]) = (Wrd28.Obj);

DEFLABEL (label_189)
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_188;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd18.Lng))))
    goto label_188;
  (Wrd10.Obj) = ((Wrd16.pObj) [11]);

DEFLABEL (label_187)
  (Rsp [1]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_188)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (current_block [OBJECT_22]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_138)
  (Wrd10.Obj) = Rvl;
  goto label_187;

DEFLABEL (label_190)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.Obj) = (current_block [OBJECT_3]);
  (Wrd39.Obj) = (current_block [OBJECT_21]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_139)
  goto label_189;

DEFLABEL (label_192)
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.Obj) = (current_block [OBJECT_5]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_113)
  (* (--Rsp)) = Rvl;
  goto label_191;

DEFLABEL (label_194)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.Obj) = (current_block [OBJECT_3]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_114)
  goto label_193;

DEFLABEL (check_application_168)
  CLOSURE_HEADER (LABEL_13);

DEFLABEL (check_application_41)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_204;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd16.Lng))))
    goto label_204;
  (Wrd10.Obj) = ((Wrd14.pObj) [10]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_203)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_33);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_196;

DEFLABEL (label_195)
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_196)
  (Wrd55.Obj) = (Rsp [1]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd56.uLng) == 10))
    goto label_202;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd54.Lng))))
    goto label_202;
  (Wrd9.Obj) = ((Wrd52.pObj) [13]);
  if (! ((Wrd9.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_195;

DEFLABEL (label_201)
  (Wrd39.Obj) = (Rsp [1]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_200;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd38.Lng))))
    goto label_200;
  (Wrd32.Obj) = (current_block [OBJECT_21]);
  ((Wrd36.pObj) [13]) = (Wrd32.Obj);

DEFLABEL (label_199)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [0]) = (Wrd11.Obj);
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_198;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd22.Lng))))
    goto label_198;
  (Wrd14.Obj) = ((Wrd20.pObj) [11]);

DEFLABEL (label_197)
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_198)
  (Wrd25.Obj) = (Rsp [1]);
  (Wrd26.Obj) = (current_block [OBJECT_22]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_142)
  (Wrd14.Obj) = Rvl;
  goto label_197;

DEFLABEL (label_200)
  (Wrd41.Obj) = (Rsp [1]);
  (Wrd42.Obj) = (current_block [OBJECT_3]);
  (Wrd43.Obj) = (current_block [OBJECT_21]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_143)
  goto label_199;

DEFLABEL (label_202)
  (Wrd57.Obj) = (Rsp [1]);
  (Wrd58.Obj) = (current_block [OBJECT_3]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_144)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_201;
  goto label_195;

DEFLABEL (label_204)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_5]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_115)
  (* (--Rsp)) = Rvl;
  goto label_203;

DEFLABEL (rvalue_passed_outB_167)
  CLOSURE_HEADER (LABEL_11);

DEFLABEL (rvalue_passed_outB_49)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_212;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd13.Lng))))
    goto label_212;
  (Wrd5.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_211)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd28.uLng) == 62))
    goto label_210;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd27.Lng))))
    goto label_210;
  (Wrd22.Obj) = ((Wrd25.pObj) [4]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_209)
  (Wrd51.Obj) = (Rsp [1]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [2]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd56.uLng) == 62))
    goto label_208;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd49.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd50.Lng))))
    goto label_208;
  (Wrd34.Obj) = ((Wrd48.pObj) [3]);

DEFLABEL (label_207)
  (Wrd66.Obj) = (* (Rsp++));
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd76.uLng) == 10))
    goto label_206;
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if (! ((Wrd71.uLng) == 26))
    goto label_206;
  (Wrd72.Lng) = (FIXNUM_TO_LONG (Wrd66.Obj));
  (Wrd73.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd74.Obj) = ((Wrd73.pObj) [0]);
  (Wrd75.Lng) = (FIXNUM_TO_LONG (Wrd74.Obj));
  if (! (((unsigned long) (Wrd72.Lng)) < ((unsigned long) (Wrd75.Lng))))
    goto label_206;
  (Wrd68.uLng) = (OBJECT_DATUM (Wrd66.Obj));
  (Wrd70.pObj) = (& ((Wrd73.pObj) [(Wrd68.Lng)]));
  (Wrd67.Obj) = ((Wrd70.pObj) [1]);

DEFLABEL (label_205)
  (Rsp [0]) = (Wrd67.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_206)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_119)
  (Wrd67.Obj) = Rvl;
  goto label_205;

DEFLABEL (label_208)
  (Wrd58.Obj) = (Rsp [1]);
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [2]);
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd57.Obj) = ((Wrd61.pObj) [0]);
  (Wrd62.Obj) = (current_block [OBJECT_10]);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 2);

DEFLABEL (label_118)
  (Wrd34.Obj) = Rvl;
  goto label_207;

DEFLABEL (label_210)
  (Wrd30.Obj) = (current_block [OBJECT_8]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 2);

DEFLABEL (label_117)
  (* (--Rsp)) = Rvl;
  goto label_209;

DEFLABEL (label_212)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_7]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_116)
  (Wrd5.Obj) = Rvl;
  goto label_211;

DEFLABEL (block_passed_outB_166)
  CLOSURE_HEADER (LABEL_9);

DEFLABEL (block_passed_outB_75)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_245;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_245;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_244)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_243;
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd28.uLng) == 26)
    goto label_214;

DEFLABEL (label_213)
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_214)
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  (Wrd29.Lng) = ((Wrd31.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd29.Lng)))
    goto label_213;
  (Wrd32.Obj) = (LONG_TO_FIXNUM (Wrd29.Lng));

DEFLABEL (label_242)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_241)
  (Wrd159.Obj) = (Rsp [1]);
  (Wrd160.uLng) = (OBJECT_TYPE (Wrd159.Obj));
  if (! ((Wrd160.uLng) == 10))
    goto label_240;
  (Wrd156.pObj) = (OBJECT_ADDRESS (Wrd159.Obj));
  (Wrd157.Obj) = ((Wrd156.pObj) [0]);
  (Wrd158.Lng) = (FIXNUM_TO_LONG (Wrd157.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd158.Lng))))
    goto label_240;
  ((Wrd156.pObj) [2]) = (Wrd32.Obj);

DEFLABEL (label_239)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_238;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd44.Lng))))
    goto label_238;
  (Wrd38.Obj) = ((Wrd42.pObj) [9]);
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_237)
  (Wrd61.Obj) = (Rsp [3]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 10))
    goto label_236;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd59.Obj) = ((Wrd58.pObj) [0]);
  (Wrd60.Lng) = (FIXNUM_TO_LONG (Wrd59.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd60.Lng))))
    goto label_236;
  (Wrd54.Obj) = ((Wrd58.pObj) [8]);
  (* (--Rsp)) = (Wrd54.Obj);

DEFLABEL (label_235)
  (Wrd69.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd72.Obj) = ((Wrd69.pObj) [0]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if ((Wrd73.uLng) == 50)
    goto label_234;
  Wrd68 = Wrd72;

DEFLABEL (label_233)
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd83.Obj) = (Rsp [1]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if (! ((Wrd84.uLng) == 10))
    goto label_232;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd83.Obj));
  (Wrd81.Obj) = ((Wrd80.pObj) [0]);
  (Wrd82.Lng) = (FIXNUM_TO_LONG (Wrd81.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd82.Lng))))
    goto label_232;
  (Wrd74.Obj) = ((Wrd80.pObj) [1]);

DEFLABEL (label_231)
  (Wrd90.Obj) = (* (Rsp++));
  if ((Wrd74.Obj) == (Wrd90.Obj))
    goto label_222;

DEFLABEL (label_221)
  (Wrd93.Obj) = (Rsp [3]);
  (Wrd94.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd92.Obj) = ((Wrd94.pObj) [2]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd92.Obj);

DEFLABEL (label_220)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_43);
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_219;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd13.Lng))))
    goto label_219;
  (Wrd7.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_218)
  (Wrd21.Obj) = (Rsp [0]);
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_215;
  (Wrd23.Obj) = (Rsp [1]);
  (Rsp [1]) = (Wrd23.Obj);
  (Rsp [2]) = (Wrd21.Obj);
  Rsp = (& (Rsp [1]));
  goto block_passed_outB_75;

DEFLABEL (label_215)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [2]);
  (Rsp [1]) = (Wrd26.Obj);
  (Wrd38.Obj) = (Rsp [2]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 10))
    goto label_217;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd37.Lng))))
    goto label_217;
  (Wrd29.Obj) = ((Wrd35.pObj) [10]);

DEFLABEL (label_216)
  (Rsp [2]) = (Wrd29.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_217)
  (Wrd40.Obj) = (Rsp [2]);
  (Wrd41.Obj) = (current_block [OBJECT_5]);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_146)
  (Wrd29.Obj) = Rvl;
  goto label_216;

DEFLABEL (label_219)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.Obj) = (current_block [OBJECT_8]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_145)
  (* (--Rsp)) = Rvl;
  goto label_218;

DEFLABEL (label_222)
  (Wrd96.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd99.Obj) = ((Wrd96.pObj) [0]);
  (Wrd100.uLng) = (OBJECT_TYPE (Wrd99.Obj));
  if ((Wrd100.uLng) == 50)
    goto label_230;
  Wrd95 = Wrd99;

DEFLABEL (label_229)
  (* (--Rsp)) = (Wrd95.Obj);
  (Wrd110.Obj) = (Rsp [1]);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd111.uLng) == 10))
    goto label_228;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd110.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd108.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd109.Lng))))
    goto label_228;
  (Wrd101.Obj) = ((Wrd107.pObj) [3]);

DEFLABEL (label_227)
  (Wrd117.Obj) = (* (Rsp++));
  if (! ((Wrd101.Obj) == (Wrd117.Obj)))
    goto label_221;
  (Wrd127.Obj) = (Rsp [0]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if (! ((Wrd128.uLng) == 10))
    goto label_226;
  (Wrd124.pObj) = (OBJECT_ADDRESS (Wrd127.Obj));
  (Wrd125.Obj) = ((Wrd124.pObj) [0]);
  (Wrd126.Lng) = (FIXNUM_TO_LONG (Wrd125.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd126.Lng))))
    goto label_226;
  (Wrd118.Obj) = ((Wrd124.pObj) [6]);

DEFLABEL (label_225)
  (Wrd136.uLng) = (OBJECT_TYPE (Wrd118.Obj));
  if (! ((Wrd136.uLng) == 1))
    goto label_224;
  (Wrd135.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
  (Wrd134.Obj) = ((Wrd135.pObj) [0]);

DEFLABEL (label_223)
  (Rsp [0]) = (Wrd134.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd144.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_53);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_52])));
  Rhp += 2;
  (Wrd143.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd144.pObj)));
  Wrd147 = Wrd144;
  (Wrd148.Obj) = (Rsp [3]);
  (Wrd149.pObj) = (OBJECT_ADDRESS (Wrd148.Obj));
  (Wrd150.Obj) = ((Wrd149.pObj) [2]);
  ((Wrd147.pObj) [2]) = (Wrd150.Obj);
  ((Wrd147.pObj) [3]) = (Wrd134.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd143.Obj);
  goto label_220;

DEFLABEL (label_224)
  (Wrd140.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd140.Obj);
  (* (--Rsp)) = (Wrd118.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_15]), 1);

DEFLABEL (label_128)
  (Wrd134.Obj) = Rvl;
  goto label_223;

DEFLABEL (label_226)
  (Wrd129.Obj) = (Rsp [0]);
  (Wrd130.Obj) = (current_block [OBJECT_14]);
  (Wrd133.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50]))));
  (* (--Rsp)) = (Wrd133.Obj);
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd129.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_127)
  (Wrd118.Obj) = Rvl;
  goto label_225;

DEFLABEL (label_228)
  (Wrd112.Obj) = (Rsp [1]);
  (Wrd113.Obj) = (current_block [OBJECT_10]);
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_126)
  (Wrd101.Obj) = Rvl;
  goto label_227;

DEFLABEL (label_230)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_48])), (Wrd96.pObj));

DEFLABEL (label_125)
  (Wrd95.Obj) = Rvl;
  goto label_229;

DEFLABEL (label_232)
  (Wrd85.Obj) = (Rsp [1]);
  (Wrd86.Obj) = (current_block [OBJECT_7]);
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_124)
  (Wrd74.Obj) = Rvl;
  goto label_231;

DEFLABEL (label_234)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_46])), (Wrd69.pObj));

DEFLABEL (label_123)
  (Wrd68.Obj) = Rvl;
  goto label_233;

DEFLABEL (label_236)
  (Wrd63.Obj) = (Rsp [3]);
  (Wrd64.Obj) = (current_block [OBJECT_13]);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_122)
  (* (--Rsp)) = Rvl;
  goto label_235;

DEFLABEL (label_238)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.Obj) = (current_block [OBJECT_12]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_121)
  (* (--Rsp)) = Rvl;
  goto label_237;

DEFLABEL (label_240)
  (Wrd161.Obj) = (Rsp [1]);
  (Wrd162.Obj) = (current_block [OBJECT_11]);
  (Wrd166.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd166.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd162.Obj);
  (* (--Rsp)) = (Wrd161.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_129)
  goto label_239;

DEFLABEL (label_243)
  (Wrd32.Obj) = (current_block [OBJECT_11]);
  goto label_242;

DEFLABEL (label_245)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_11]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_120)
  (* (--Rsp)) = Rvl;
  goto label_244;

DEFLABEL (continuation_55)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd32.Obj) = Rvl;
  goto label_241;

DEFLABEL (lvalue_externally_visibleB_165)
  CLOSURE_HEADER (LABEL_7);

DEFLABEL (lvalue_externally_visibleB_81)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_254;
  Wrd5 = Wrd9;

DEFLABEL (label_253)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_252;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_252;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_251)
  (Wrd27.Obj) = (* (Rsp++));
  if ((Wrd11.Obj) == (Wrd27.Obj))
    goto label_248;

DEFLABEL (label_247)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  goto lvalue_passed_inB_90;

DEFLABEL (continuation_80)
  INTERRUPT_CHECK (27, LABEL_56);

DEFLABEL (label_246)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd52.Obj) = ((Wrd54.pObj) [2]);
  (Rsp [0]) = (Wrd52.Obj);
  goto lvalue_passed_outB_103;

DEFLABEL (label_248)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd44.Obj) = (Rsp [2]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 10))
    goto label_250;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [0]);
  (Wrd43.Lng) = (FIXNUM_TO_LONG (Wrd42.Obj));
  if (! (((unsigned long) 19L) < ((unsigned long) (Wrd43.Lng))))
    goto label_250;
  (Wrd37.Obj) = ((Wrd41.pObj) [20]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_249)
  (Wrd51.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60]));

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_55);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_247;
  goto label_246;

DEFLABEL (label_250)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.Obj) = (current_block [OBJECT_16]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_132)
  (* (--Rsp)) = Rvl;
  goto label_249;

DEFLABEL (label_252)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_7]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_131)
  (Wrd11.Obj) = Rvl;
  goto label_251;

DEFLABEL (label_254)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57])), (Wrd6.pObj));

DEFLABEL (label_130)
  (Wrd5.Obj) = Rvl;
  goto label_253;

DEFLABEL (lvalue_passed_outB_164)
DEFLABEL (lvalue_passed_outB_103)
  INTERRUPT_CHECK (26, LABEL_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_265;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd16.Lng))))
    goto label_265;
  (Wrd10.Obj) = ((Wrd14.pObj) [13]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_264)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_263;
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd28.uLng) == 26)
    goto label_256;

DEFLABEL (label_255)
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_256)
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  (Wrd29.Lng) = ((Wrd31.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd29.Lng)))
    goto label_255;
  (Wrd32.Obj) = (LONG_TO_FIXNUM (Wrd29.Lng));

DEFLABEL (label_262)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_261)
  (Wrd62.Obj) = (Rsp [1]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_260;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd61.Lng))))
    goto label_260;
  ((Wrd59.pObj) [13]) = (Wrd32.Obj);

DEFLABEL (label_259)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_258;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd44.Lng))))
    goto label_258;
  (Wrd38.Obj) = ((Wrd42.pObj) [7]);
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_257)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66]))));
  (* (--Rsp)) = (Wrd53.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_64);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90]));

DEFLABEL (continuation_102)
  INTERRUPT_CHECK (27, LABEL_89);
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_258)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.Obj) = (current_block [OBJECT_18]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_134)
  (* (--Rsp)) = Rvl;
  goto label_257;

DEFLABEL (label_260)
  (Wrd64.Obj) = (Rsp [1]);
  (Wrd65.Obj) = (current_block [OBJECT_3]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_135)
  goto label_259;

DEFLABEL (label_263)
  (Wrd32.Obj) = (current_block [OBJECT_11]);
  goto label_262;

DEFLABEL (label_265)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_133)
  (* (--Rsp)) = Rvl;
  goto label_264;

DEFLABEL (continuation_97)
  INTERRUPT_CHECK (27, LABEL_61);
  (Wrd32.Obj) = Rvl;
  goto label_261;

DEFLABEL (Z__rvalue_passed_outB_174)
DEFLABEL (Z__rvalue_passed_outB_53)
  INTERRUPT_CHECK (26, LABEL_21);
  (Wrd5.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_274;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd18.Lng))))
    goto label_274;
  (Wrd12.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_273)
  (Wrd26.Obj) = (Rsp [0]);
  if ((Wrd26.Obj) == ((SCHEME_OBJECT) 0))
    goto label_272;
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd30.uLng) == 26)
    goto label_267;

DEFLABEL (label_266)
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_267)
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd31.Lng) = ((Wrd33.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd31.Lng)))
    goto label_266;
  (Wrd34.Obj) = (LONG_TO_FIXNUM (Wrd31.Lng));

DEFLABEL (label_271)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_270)
  (Rsp [2]) = (Wrd34.Obj);
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 10)
    goto label_269;

DEFLABEL (label_268)
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_269)
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd45.Lng))))
    goto label_268;
  ((Wrd43.pObj) [2]) = (Wrd34.Obj);
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_272)
  (Wrd34.Obj) = (current_block [OBJECT_11]);
  goto label_271;

DEFLABEL (label_274)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_11]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_136)
  (* (--Rsp)) = Rvl;
  goto label_273;

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_71);
  (Wrd34.Obj) = Rvl;
  goto label_270;

DEFLABEL (lambda_171)
  CLOSURE_HEADER (LABEL_24);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [6]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_278;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_278;
  (Wrd12.Obj) = ((Wrd18.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_277)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [2]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto block_passed_outB_75;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_73);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [6]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_276;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd20.Lng))))
    goto label_276;
  (Wrd12.Obj) = ((Wrd18.pObj) [4]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_275)
  goto lvalue_passed_inB_90;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_96);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111]))));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_110);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [4]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_276)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [6]);
  (Wrd28.Obj) = (current_block [OBJECT_8]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_151)
  (* (--Rsp)) = Rvl;
  goto label_275;

DEFLABEL (label_278)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [6]);
  (Wrd28.Obj) = (current_block [OBJECT_10]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_137)
  (* (--Rsp)) = Rvl;
  goto label_277;

DEFLABEL (lambda_175)
DEFLABEL (lambda_31)
  INTERRUPT_CHECK (26, LABEL_29);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_285;
  Wrd5 = Wrd9;

DEFLABEL (label_284)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_283;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_283;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_282)
  (Wrd27.Obj) = (* (Rsp++));
  if ((Wrd11.Obj) == (Wrd27.Obj))
    goto label_280;
  Rvl = (current_block [OBJECT_21]);
  goto label_279;

DEFLABEL (label_280)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_279)
DEFLABEL (label_281)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_283)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.Obj) = (current_block [OBJECT_7]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_141)
  (Wrd11.Obj) = Rvl;
  goto label_282;

DEFLABEL (label_285)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_77])), (Wrd6.pObj));

DEFLABEL (label_140)
  (Wrd5.Obj) = Rvl;
  goto label_284;

DEFLABEL (lambda_172)
  CLOSURE_HEADER (LABEL_52);

DEFLABEL (lambda_67)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  if ((Wrd5.Obj) == (Wrd8.Obj))
    goto label_286;
  (Wrd9.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd9.Obj);
  goto lvalue_externally_visibleB_81;

DEFLABEL (label_286)
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lvalue_passed_inB_176)
DEFLABEL (lvalue_passed_inB_90)
  INTERRUPT_CHECK (26, LABEL_85);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_297;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd13.Lng))))
    goto label_297;
  (Wrd7.Obj) = ((Wrd11.pObj) [12]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_296)
  (Wrd21.Obj) = (Rsp [0]);
  if (! ((Wrd21.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_289;
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd69.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd70.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd70.Obj);
  goto Z__lvalue_passed_inB_95;

DEFLABEL (continuation_85)
  INTERRUPT_CHECK (27, LABEL_87);
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_288;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd15.Lng))))
    goto label_288;
  (Wrd7.Obj) = ((Wrd13.pObj) [6]);

DEFLABEL (label_287)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_288)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_14]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_152)
  (Wrd7.Obj) = Rvl;
  goto label_287;

DEFLABEL (label_289)
  if ((Wrd21.Obj) == (current_block [OBJECT_24]))
    goto label_295;
  (Wrd25.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd32.uLng) == 26))
    goto label_294;
  (Wrd35.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  (Wrd33.Lng) = ((Wrd35.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd33.Lng)))
    goto label_294;
  (Wrd30.Obj) = (LONG_TO_FIXNUM (Wrd33.Lng));

DEFLABEL (label_293)
  (Rsp [2]) = (Wrd30.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_23]);
  (Rsp [1]) = (Wrd36.Obj);
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if ((Wrd49.uLng) == 10)
    goto label_291;

DEFLABEL (label_290)
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_291)
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [0]);
  (Wrd47.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd47.Lng))))
    goto label_290;
  ((Wrd45.pObj) [12]) = (Wrd30.Obj);

DEFLABEL (label_292)
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_294)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_148)
  (Wrd30.Obj) = Rvl;
  goto label_293;

DEFLABEL (label_295)
  (Wrd50.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd51.Obj) = (current_block [OBJECT_23]);
  (Rsp [1]) = (Wrd51.Obj);
  (Wrd52.Obj) = (current_block [OBJECT_11]);
  (Rsp [2]) = (Wrd52.Obj);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd65.uLng) == 10))
    goto label_290;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd62.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd63.Lng))))
    goto label_290;
  ((Wrd61.pObj) [12]) = (Wrd52.Obj);
  goto label_292;

DEFLABEL (label_297)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_23]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_147)
  (* (--Rsp)) = Rvl;
  goto label_296;

DEFLABEL (Z__lvalue_passed_outB_177)
DEFLABEL (Z__lvalue_passed_outB_107)
  INTERRUPT_CHECK (26, LABEL_66);
  (Wrd5.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_306;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd18.Lng))))
    goto label_306;
  (Wrd12.Obj) = ((Wrd16.pObj) [13]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_305)
  (Wrd26.Obj) = (Rsp [0]);
  if ((Wrd26.Obj) == ((SCHEME_OBJECT) 0))
    goto label_304;
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd30.uLng) == 26)
    goto label_299;

DEFLABEL (label_298)
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_299)
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd31.Lng) = ((Wrd33.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd31.Lng)))
    goto label_298;
  (Wrd34.Obj) = (LONG_TO_FIXNUM (Wrd31.Lng));

DEFLABEL (label_303)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_302)
  (Rsp [2]) = (Wrd34.Obj);
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 10)
    goto label_301;

DEFLABEL (label_300)
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_301)
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd45.Lng))))
    goto label_300;
  ((Wrd43.pObj) [13]) = (Wrd34.Obj);
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_304)
  (Wrd34.Obj) = (current_block [OBJECT_11]);
  goto label_303;

DEFLABEL (label_306)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_3]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_149)
  (* (--Rsp)) = Rvl;
  goto label_305;

DEFLABEL (continuation_105)
  INTERRUPT_CHECK (27, LABEL_91);
  (Wrd34.Obj) = Rvl;
  goto label_302;

DEFLABEL (lambda_173)
  CLOSURE_HEADER (LABEL_68);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_308;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_308;
  (Wrd8.Obj) = ((Wrd14.pObj) [4]);

DEFLABEL (label_307)
  (Rsp [1]) = (Wrd8.Obj);
  goto lvalue_passed_outB_103;

DEFLABEL (label_308)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_8]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_150)
  (Wrd8.Obj) = Rvl;
  goto label_307;

DEFLABEL (Z__lvalue_passed_inB_178)
DEFLABEL (Z__lvalue_passed_inB_95)
  INTERRUPT_CHECK (26, LABEL_100);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_312;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd31.Lng))))
    goto label_312;
  (Wrd25.Obj) = (Rsp [1]);
  ((Wrd29.pObj) [12]) = (Wrd25.Obj);

DEFLABEL (label_311)
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 10))
    goto label_310;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd13.Lng))))
    goto label_310;
  (Wrd5.Obj) = ((Wrd11.pObj) [11]);

DEFLABEL (label_309)
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (Rsp [0]) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_310)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (current_block [OBJECT_22]);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_153)
  (Wrd5.Obj) = Rvl;
  goto label_309;

DEFLABEL (label_312)
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.Obj) = (current_block [OBJECT_23]);
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_154)
  goto label_311;

DEFLABEL (lambda_179)
DEFLABEL (lambda_23)
  INTERRUPT_CHECK (26, LABEL_94);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_325;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_325;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_324)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == ((SCHEME_OBJECT) 0))
    goto label_323;
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd28.uLng) == 26)
    goto label_314;

DEFLABEL (label_313)
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_314)
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  (Wrd29.Lng) = ((Wrd31.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd29.Lng)))
    goto label_313;
  (Wrd32.Obj) = (LONG_TO_FIXNUM (Wrd29.Lng));

DEFLABEL (label_322)
  Rsp = (& (Rsp [2]));

DEFLABEL (label_321)
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_320;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd60.Obj) = ((Wrd59.pObj) [0]);
  (Wrd61.Lng) = (FIXNUM_TO_LONG (Wrd60.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd61.Lng))))
    goto label_320;
  ((Wrd59.pObj) [2]) = (Wrd32.Obj);

DEFLABEL (label_319)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd45.Obj) = (Rsp [1]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 10))
    goto label_318;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd44.Lng))))
    goto label_318;
  (Wrd38.Obj) = ((Wrd42.pObj) [6]);
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_317)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd53.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_108);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_316;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd15.Lng))))
    goto label_316;
  (Wrd7.Obj) = ((Wrd13.pObj) [7]);

DEFLABEL (label_315)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54]));

DEFLABEL (label_316)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (current_block [OBJECT_18]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_160)
  (Wrd7.Obj) = Rvl;
  goto label_315;

DEFLABEL (label_318)
  (Wrd47.Obj) = (Rsp [1]);
  (Wrd48.Obj) = (current_block [OBJECT_14]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_156)
  (* (--Rsp)) = Rvl;
  goto label_317;

DEFLABEL (label_320)
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.Obj) = (current_block [OBJECT_11]);
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (label_157)
  goto label_319;

DEFLABEL (label_323)
  (Wrd32.Obj) = (current_block [OBJECT_11]);
  goto label_322;

DEFLABEL (label_325)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_11]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_155)
  (* (--Rsp)) = Rvl;
  goto label_324;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_105);
  (Wrd32.Obj) = Rvl;
  goto label_321;

DEFLABEL (lambda_180)
DEFLABEL (lambda_87)
  INTERRUPT_CHECK (26, LABEL_98);
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 10))
    goto label_328;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 11L) < ((unsigned long) (Wrd18.Lng))))
    goto label_328;
  (Wrd7.Obj) = ((Wrd16.pObj) [12]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_327;

DEFLABEL (label_326)
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_327)
  (Wrd9.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_24]);
  (Rsp [1]) = (Wrd10.Obj);
  goto Z__lvalue_passed_inB_95;

DEFLABEL (label_328)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.Obj) = (current_block [OBJECT_23]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_158)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_327;
  goto label_326;

DEFLABEL (lambda_181)
DEFLABEL (lambda_93)
  INTERRUPT_CHECK (26, LABEL_103);
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_331;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd16.Lng))))
    goto label_331;
  (Wrd7.Obj) = ((Wrd14.pObj) [13]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_330;

DEFLABEL (label_329)
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_330)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114]));

DEFLABEL (label_331)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_3]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_159)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_330;
  goto label_329;

DEFLABEL (lambda_182)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_111);
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_336;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd32.Lng))))
    goto label_336;
  (Wrd7.Obj) = ((Wrd30.pObj) [8]);
  if (! ((Wrd7.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_333;

DEFLABEL (label_332)
  Rvl = (current_block [OBJECT_20]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_333)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_335;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd19.Lng))))
    goto label_335;
  (Wrd11.Obj) = ((Wrd17.pObj) [8]);

DEFLABEL (label_334)
  (Rsp [0]) = (Wrd11.Obj);
  goto lvalue_passed_inB_90;

DEFLABEL (label_335)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.Obj) = (current_block [OBJECT_13]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_161)
  (Wrd11.Obj) = Rvl;
  goto label_334;

DEFLABEL (label_336)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_13]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6]), 2);

DEFLABEL (label_162)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_332;
  goto label_333;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

int
decl_outer_so_2998375ed3a84b78 (void)
{
  return (0);
}

DECLARE_COMPILED_CODE ("outer.so", 96, decl_outer_so_2998375ed3a84b78, outer_so_2998375ed3a84b78)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_outer_so_data_2998375ed3a84b78 [1228] =
  "\xf9\x01\x01\xfa\x01\x1d\x0c\x0d\x0d\x0d\x02\x02\x07\x1d\x0d\x86"
  "\x0d\x02\xc1\x85\x02\x02\x81\x82\xc2\x83\x80\xc2\x02\xc3\x02\xc3"
  "\xc3\x0d\x0d\x0d\x0d\x0d\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
  "\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59"
  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77"
  "\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72"
  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73"
  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74\x2f\x6f"
  "\x75\x74\x65\x72\x2e\x69\x6e\x66\x06\x62\x6c\x6f\x63\x6b\x0a\x70"
  "\x72\x6f\x63\x65\x64\x75\x72\x65\x0a\x69\x6e\x68\x65\x72\x69\x74"
  "\x65\x64\x0c\x0b\x02\x0a\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x09"
  "\x63\x6f\x6e\x73\x74\x61\x6e\x74\x14\x04\x63\x61\x72\x08\x09\x0c"
  "\x25\x72\x65\x63\x6f\x72\x64\x2d\x72\x65\x66\x0b\x76\x65\x63\x74"
  "\x6f\x72\x2d\x72\x65\x66\x0a\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73"
  "\x65\x74\x21\x0d\x13\x6c\x65\x78\x69\x63\x61\x6c\x2d\x61\x73\x73"
  "\x69\x67\x6e\x6d\x65\x6e\x74\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73"
  "\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0f\x6f\x75\x74\x65\x72\x2d\x61"
  "\x6e\x61\x6c\x79\x73\x69\x73\x0d\x72\x76\x61\x6c\x75\x65\x2d\x74"
  "\x79\x70\x65\x73\x0e\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x2d\x74"
  "\x61\x67\x1c\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x2d"
  "\x74\x79\x70\x65\x2f\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x0d\x76"
  "\x61\x72\x69\x61\x62\x6c\x65\x2d\x74\x61\x67\x05\x04\x12\x6d\x61"
  "\x6b\x65\x2d\x6d\x65\x74\x68\x6f\x64\x2d\x74\x61\x62\x6c\x65\x05"
  "\x13\x74\x72\x61\x6e\x73\x69\x74\x69\x76\x65\x2d\x63\x6c\x6f\x73"
  "\x75\x72\x65\x03\x0e\x72\x76\x61\x6c\x75\x65\x2d\x76\x61\x6c\x75"
  "\x65\x73\x03\x12\x72\x76\x61\x6c\x75\x65\x2d\x70\x61\x73\x73\x65"
  "\x64\x2d\x69\x6e\x3f\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x04"
  "\x05\x6d\x65\x6d\x71\x05\x1a\x64\x65\x66\x69\x6e\x65\x2d\x6d\x65"
  "\x74\x68\x6f\x64\x2d\x74\x61\x62\x6c\x65\x2d\x65\x6e\x74\x72\x79"
  "\x04\x0e\x74\x68\x65\x72\x65\x2d\x65\x78\x69\x73\x74\x73\x3f\x03"
  "\x0e\x6c\x76\x61\x6c\x75\x65\x2d\x76\x61\x6c\x75\x65\x73\x03\x0e"
  "\x65\x6e\x71\x75\x65\x75\x65\x2d\x6e\x6f\x64\x65\x21\x0b\x60\xc2"
  "\x01\x80\x80\x04\x5f\xc0\x01\x81\x81\x02\x5e\xbe\x01\x81\x83\x02"
  "\x5d\xbc\x01\x81\x83\x02\x5c\xba\x01\x83\x04\x5b\xb8\x01\x81\x83"
  "\x02\x5a\xb6\x01\x81\x85\x02\x59\xb4\x01\x81\x83\x02\x58\xb2\x01"
  "\x81\x91\x02\x57\xb0\x01\x81\x83\x02\x56\xae\x01\x83\x04\x55\xac"
  "\x01\x81\x83\x02\x54\xaa\x01\x83\x04\x53\xa8\x01\x81\x83\x02\x52"
  "\xa6\x01\x81\x85\x02\x51\xa4\x01\x81\x83\x02\x50\xa2\x01\x81\x85"
  "\x02\x4f\xa0\x01\x83\x04\x4e\x9e\x01\x81\x83\x02\x4d\x9c\x01\x81"
  "\x91\x02\x4c\x9a\x01\x81\x85\x02\x4b\x98\x01\x81\x85\x02\x4a\x96"
  "\x01\x81\x85\x02\x49\x94\x01\x81\x85\x02\x48\x92\x01\x81\x85\x02"
  "\x47\x90\x01\x81\x85\x02\x46\x8e\x01\x81\x85\x02\x45\x8c\x01\x81"
  "\x83\x02\x44\x8a\x01\x81\x85\x02\x43\x88\x01\x81\x85\x02\x42\x86"
  "\x01\x81\x91\x02\x41\x84\x01\x81\x89\x02\x40\x82\x01\x83\x04\x3f"
  "\x80\x01\x81\x87\x02\x3e\x7e\x81\x85\x02\x3d\x7c\x81\x87\x02\x3c"
  "\x7a\x81\x83\x02\x3b\x78\x83\x04\x3a\x76\x81\x85\x02\x39\x74\x81"
  "\x87\x02\x38\x72\x81\x85\x02\x37\x70\x81\x85\x02\x36\x6e\x81\x85"
  "\x02\x35\x6c\x81\x85\x02\x34\x6a\x81\x85\x02\x33\x68\x81\x85\x02"
  "\x32\x66\x81\x89\x02\x31\x64\x81\x85\x02\x30\x62\x81\x83\x02\x2f"
  "\x60\x83\x04\x2e\x5e\x81\x85\x02\x2d\x5c\x81\x85\x02\x2c\x5a\x81"
  "\x85\x02\x2b\x58\x81\x85\x02\x2a\x56\x81\x83\x02\x29\x54\x81\x89"
  "\x02\x28\x52\x83\x04\x27\x50\x81\x87\x02\x26\x4e\x81\x91\x02\x25"
  "\x4c\x81\x87\x02\x24\x4a\x81\x85\x02\x23\x48\x81\x87\x02\x22\x46"
  "\x81\x85\x02\x21\x44\x81\x85\x02\x20\x42\x81\x87\x02\x1f\x40\x81"
  "\x87\x02\x1e\x3e\x81\x85\x02\x1d\x3c\x81\x85\x02\x1c\x3a\x81\x85"
  "\x02\x1b\x38\x81\x85\x02\x1a\x36\x81\x8b\x02\x19\x34\x81\x8b\x02"
  "\x18\x32\x81\x8d\x02\x17\x30\x81\x8b\x02\x16\x2e\x81\x8d\x02\x15"
  "\x2c\x81\x8b\x02\x14\x2a\x81\x89\x02\x13\x28\x81\x87\x02\x12\x26"
  "\x81\x85\x02\x11\x24\x81\x87\x02\x10\x22\x81\x85\x02\x0f\x20\x81"
  "\x85\x02\x0e\x1e\x81\x85\x02\x0d\x1c\x81\x87\x02\x0c\x1a\x81\x85"
  "\x02\x0b\x18\x81\x85\x02\x0a\x16\x81\x85\x02\x09\x14\x81\x87\x02"
  "\x08\x12\x81\x85\x02\x07\x10\x81\x8b\x02\x06\x0e\x81\x85\x02\x05"
  "\x0c\x81\x85\x02\x04\x0a\x81\x89\x02\x03\x08\x81\x95\x02\x02\x06"
  "\x81\x91\x02\x01\x04\x81\x83\x02\xc1\x01\xf9\x01";

SCHEME_OBJECT *
outer_so_data_2998375ed3a84b78 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_outer_so_data_2998375ed3a84b78 [0]))), (sizeof (prog_outer_so_data_2998375ed3a84b78)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_119]));
}

DECLARE_COMPILED_DATA_NS ("outer.so", outer_so_data_2998375ed3a84b78)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("outer.so", "e139a8b91971d8b2")
